rwslib is an open source product of Medidata Solutions Inc with contributions from the community

Authors
```````

- Ian Sparks <isparks@mdsol.com> / <isparks@trialgrid.com>
- Geoff Low <glow@mdsol.com>
- Andrew Newbigging <anewbigging@mdsol.com>
- Oli Quinet <https://github.com/Oli76>
- Daniel Smoczyk <https://github.com/dPeS>
- Bastien Gerard <https://github.com/bagerard>
- Filip Janowski <https://github.com/filip75>
- halb0w <https://github.com/halbow>
